@@ -1,17 +1,14 @@
 # -*- coding: utf-8 -*-
 import time
 import ACLMessage
+import AID
 import MessageReceiver
 import threading
 import types
 import copy
-import colors
-import sys
-import traceback
-
-from xmpp import Node, Message, Presence, Iq
 import xmpp
 import re
+import json
 
 
 class BehaviourTemplate:
@@ -58,7 +55,7 @@ class ACLTemplate(BehaviourTemplate):
     """
     Template for message matching
     """
-    def __init__(self, performative=None):
+    def __init__(self, performative=None, jsonstring=None):
         self.performative = performative
         self.sender = None
         self.receivers = []
@@ -74,8 +71,66 @@ class ACLTemplate(BehaviourTemplate):
         self.conversation_id = None
         #self.userDefProps = None
 
+        if jsonstring!=None:
+            self.loadJSON(jsonstring)
+
     def __str__(self):
-        return str({"performative": self.performative, "sender": str(self.sender), "receivers": str(self.receivers), "reply_to": self.reply_to, "content": self.content, "reply_with": self.reply_with, "reply_by": self.reply_by, "in_reply_to": self.in_reply_to, "encoding": self.encoding, "language": self.language, "ontology": self.ontology, "protocol": self.protocol, "conversation_id": self.conversation_id})
+        d = {"performative": self.performative, "sender": str(self.sender), "receivers": str(self.receivers), "reply_to": self.reply_to, "content": self.content, "reply_with": self.reply_with, "reply_by": self.reply_by, "in_reply_to": self.in_reply_to, "encoding": self.encoding, "language": self.language, "ontology": self.ontology, "protocol": self.protocol, "conversation_id": self.conversation_id}
+        return str(dict((data for data in d.iteritems() if data[1])))
+
+    def loadJSON(self, jsonstring):
+        """
+        loads a JSON string in the message
+        """
+        p = json.loads(jsonstring)
+
+        if "performative" in p:
+            self.setPerformative(p["performative"])
+
+        if "sender" in p:
+            s = AID.aid()
+            s.loadJSON(p["sender"])
+            self.setSender(s)
+
+        if "receivers" in p:
+            for i in p["receivers"]:
+                s = AID.aid()
+                s.loadJSON(i)
+                self.addReceiver(s)
+
+        if "content" in p:
+            self.setContent(p["content"])
+
+        if "reply-with" in p:
+            self.setReplyWith(p["reply-with"])
+
+        if "reply-by" in p:
+            self.setReplyBy(p["reply-by"])
+
+        if "in-reply-to" in p:
+            self.setInReplyTo(p["in-reply-to"])
+
+        if "reply-to" in p:
+            for i in p["reply-to"]:
+                s = AID.aid()
+            s.loadJSON(i)
+            self.addReplyTo(s)
+
+        if "language" in p:
+            self.setLanguage(p["language"])
+
+        if "encoding" in p:
+            self.setEncoding(p["encoding"])
+
+        if "ontology" in p:
+            self.setOntology(p['ontology'])
+
+        if "protocol" in p:
+            self.setProtocol(p['protocol'])
+
+        if "conversation-id" in p:
+            self.setConversationId(p["conversation-id"])
+
 
     def reset(self):
         self.__init__()
@@ -167,6 +222,60 @@ class ACLTemplate(BehaviourTemplate):
     def getConversationId(self):
         return self.conversation_id
 
+    def match(self, message):
+    #def acl_match(self, message):
+        if message.__class__ != ACLMessage.ACLMessage:
+            return False
+        if (self.getPerformative() is not None):
+            if (self.getPerformative() != message.getPerformative()):
+                return False
+        if (self.getConversationId() is not None):
+            if (str(self.getConversationId()) != str(message.getConversationId())):
+                return False
+        if (self.sender is not None):
+            if message.sender is not None:
+                if not message.sender.match(self.sender):
+                    return False
+            else:
+                return False
+        if (self.receivers != []):
+            for tr in self.receivers:
+                found = False
+                for mr in message.receivers:
+                    if mr.match(tr):
+                        found = True
+                        break
+                if not found:
+                    return False
+        if (self.getReplyTo() != []):
+            if (self.getReplyTo() != message.getReplyTo()):
+                return False
+        if (self.content is not None):
+            if (self.content != message.content):
+                return False
+        if (self.getReplyWith() is not None):
+            if (self.getReplyWith() != message.getReplyWith()):
+                return False
+        if (self.getReplyBy() is not None):
+            if (self.getReplyBy() != message.getReplyBy()):
+                return False
+        if (self.getInReplyTo() is not None):
+            if (self.getInReplyTo() != message.getInReplyTo()):
+                return False
+        if (self.getEncoding() is not None):
+            if (self.getEncoding() != message.getEncoding()):
+                return False
+        if (self.getLanguage() is not None):
+            if (self.getLanguage() != message.getLanguage()):
+                return False
+        if (self.getOntology() is not None):
+            if (self.getOntology() != message.getOntology()):
+                return False
+        if (self.getProtocol() is not None):
+            if (self.getProtocol() != message.getProtocol()):
+                return False
+        return True
+
 
 class NOTTemplate(BehaviourTemplate):
     def __init__(self, expr):
@@ -214,67 +323,22 @@ class PresenceTemplate(BehaviourTemplate):
 
 
 class MessageTemplate(BehaviourTemplate):
-    def __init__(self, Template, regex=False):
+    def __init__(self, template, regex=False):
         # Discriminate Template class
         BehaviourTemplate.__init__(self, regex)
-        if isinstance(Template, types.InstanceType):
-            if Template.__class__ == ACLTemplate:
-                self.match = self.acl_match
-            else:
-                # Default template option
+        self.template = copy.copy(template)
+        if isinstance(template, ACLMessage.ACLMessage):
+                self.template = ACLTemplate(jsonstring=template.asJSON())
+                self.match = self.template.match
+        elif "Message" in str(self.template.__class__) or "Presence" in str(self.template.__class__) or "Iq" in str(self.template.__class__) or "Node" in str(self.template.__class__):
                 self.match = self.node_match
+        else:  #isinstance(template, ACLTemplate):
+                self.match = self.template.match
+                # Default template option
 
-        self.template = copy.copy(Template)
+    def __str__(self):
+        return str(self.template)
 
-    def acl_match(self, message):
-        if message.__class__ != ACLMessage.ACLMessage:
-            return False
-        if (self.template.getPerformative() is not None):
-            if (self.template.getPerformative() != message.getPerformative()):
-                return False
-        if (self.template.getConversationId() is not None):
-            if (str(self.template.getConversationId()) != str(message.getConversationId())):
-                return False
-        if (self.template.sender is not None):
-            if not message.sender.match(self.template.sender):
-                return False
-        if (self.template.receivers != []):
-            for tr in self.template.receivers:
-                found = False
-                for mr in message.receivers:
-                    if mr.match(tr):
-                        found = True
-                        break
-                if not found:
-                    return False
-        if (self.template.getReplyTo() != []):
-            if (self.template.getReplyTo() != message.getReplyTo()):
-                return False
-        if (self.template.content is not None):
-            if (self.template.content != message.content):
-                return False
-        if (self.template.getReplyWith() is not None):
-            if (self.template.getReplyWith() != message.getReplyWith()):
-                return False
-        if (self.template.getReplyBy() is not None):
-            if (self.template.getReplyBy() != message.getReplyBy()):
-                return False
-        if (self.template.getInReplyTo() is not None):
-            if (self.template.getInReplyTo() != message.getInReplyTo()):
-                return False
-        if (self.template.getEncoding() is not None):
-            if (self.template.getEncoding() != message.getEncoding()):
-                return False
-        if (self.template.getLanguage() is not None):
-            if (self.template.getLanguage() != message.getLanguage()):
-                return False
-        if (self.template.getOntology() is not None):
-            if (self.template.getOntology() != message.getOntology()):
-                return False
-        if (self.template.getProtocol() is not None):
-            if (self.template.getProtocol() != message.getProtocol()):
-                return False
-        return True
 
     def node_match(self, other):
         """
@@ -299,11 +363,11 @@ class MessageTemplate(BehaviourTemplate):
                     return False
             if self.template.attrs is not None and self.template.attrs != {}:
                 for i, j in self.template.attrs.items():
-                    if (i, j) not in (other.attrs.items()):  # not in other.attrs.items():
-                        if not self.regex:
-                            return False
-                        if not re.match(str(j), str(other.attrs[i])):
+                    if not self.regex:
+                        if (i not in other.attrs.keys()) or (str(j) != str(other.attrs[i])):
                             return False
+                    if not re.match(str(j), str(other.attrs[i])):
+                        return False
             if self.template.data is not None and self.template.data != []:
                 if self.template.data != other.data:
                     if not self.regex:
@@ -330,10 +394,10 @@ class MessageTemplate(BehaviourTemplate):
                     # If we reach this point, there is no hope left . . . (no match among the suspects)
                     return False
 
-        except Exception, e:
-            #print "Exception in node_match:", e
+        except Exception:
             return False
         # Arriving here means this is a perfect match
+
         return True
 
     def presence_match(self, message):  # frm=None, type=None, status=None, show=None):
@@ -353,8 +417,8 @@ class MessageTemplate(BehaviourTemplate):
             return False
 
         if self._frm:
-            if not JID(self._frm).getResource():
-                if self._frm != JID(frm).getBareJID():
+            if not xmpp.JID(self._frm).getResource():
+                if self._frm != xmpp.JID(frm).getBareJID():
                     return False
             else:
                 if self._frm != frm:
@@ -368,7 +432,6 @@ class MessageTemplate(BehaviourTemplate):
     def iq_match(self, iq):
         return self.node_match(iq)
 
-
 class Behaviour(MessageReceiver.MessageReceiver):
     def __init__(self):
         MessageReceiver.MessageReceiver.__init__(self)
@@ -447,7 +510,7 @@ class Behaviour(MessageReceiver.MessageReceiver):
         """
         try:
             self._forceKill.set()
-            self.myAgent.DEBUG("Stoping Behavior " + str(self), "info")
+            self.myAgent.DEBUG("Stopping Behavior " + str(self), "info")
         except:
             #Behavior is already dead
             self.myAgent.DEBUG("Behavior " + str(self) + " is already dead", "warn")
